==> knative-model-4.12.0-sources.jar: annotations/io/fabric8/knative/eventing/contrib/gitlab/v1alpha1/GitLabSourceListBuilder.java <==
package io.fabric8.knative.eventing.contrib.gitlab.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class GitLabSourceListBuilder extends GitLabSourceListFluentImpl<GitLabSourceListBuilder> implements VisitableBuilder<GitLabSourceList,GitLabSourceListBuilder> {

    GitLabSourceListFluent<?> fluent;
    Boolean validationEnabled;

    public GitLabSourceListBuilder() { 
        this(true);
    }


    public GitLabSourceListBuilder(Boolean validationEnabled) { 
        this(new GitLabSourceList(), validationEnabled);
    }


    public GitLabSourceListBuilder(GitLabSourceListFluent<?> fluent) { 
        this(fluent, true);
    }


    public GitLabSourceListBuilder(GitLabSourceListFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new GitLabSourceList(), validationEnabled);
    }


    public GitLabSourceListBuilder(GitLabSourceListFluent<?> fluent,GitLabSourceList instance) { 
        this(fluent, instance, true);
    }


    public GitLabSourceListBuilder(GitLabSourceListFluent<?> fluent,GitLabSourceList instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withItems(instance.getItems()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }


    public GitLabSourceListBuilder(GitLabSourceList instance) { 
        this(instance,true);
    }


    public GitLabSourceListBuilder(GitLabSourceList instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withItems(instance.getItems()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }


    public GitLabSourceList build() {
        GitLabSourceList buildable = new GitLabSourceList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        GitLabSourceListBuilder that = (GitLabSourceListBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> knative-model-5.1.1-sources.jar: annotations/io/fabric8/knative/eventing/contrib/gitlab/v1alpha1/GitLabSourceListBuilder.java <==
package io.fabric8.knative.eventing.contrib.gitlab.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class GitLabSourceListBuilder extends GitLabSourceListFluentImpl<GitLabSourceListBuilder> implements VisitableBuilder<GitLabSourceList,GitLabSourceListBuilder> {

    GitLabSourceListFluent<?> fluent;
    Boolean validationEnabled;

    public GitLabSourceListBuilder() {
        this(true);
    }

    public GitLabSourceListBuilder(Boolean validationEnabled) {
        this(new GitLabSourceList(), validationEnabled);
    }

    public GitLabSourceListBuilder(GitLabSourceListFluent<?> fluent) {
        this(fluent, true);
    }

    public GitLabSourceListBuilder(GitLabSourceListFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new GitLabSourceList(), validationEnabled);
    }

    public GitLabSourceListBuilder(GitLabSourceListFluent<?> fluent,GitLabSourceList instance) {
        this(fluent, instance, true);
    }

    public GitLabSourceListBuilder(GitLabSourceListFluent<?> fluent,GitLabSourceList instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withItems(instance.getItems()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public GitLabSourceListBuilder(GitLabSourceList instance) {
        this(instance,true);
    }

    public GitLabSourceListBuilder(GitLabSourceList instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withItems(instance.getItems()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.knative.eventing.contrib.gitlab.v1alpha1.EditableGitLabSourceList build() {
        EditableGitLabSourceList buildable = new EditableGitLabSourceList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        GitLabSourceListBuilder that = (GitLabSourceListBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
